export function isRequired(field: any): any;
export function pathParse(path: any): any;
export function pathsEqual(a: any, b: any): any;
export function generateIndexForType(type: any): any;
export function generateIdForType(type: any): string;
/**
 * @template T
 * @param {T} data
 * @param {(this: any, key: string, value: any) => any} [replacer]
 * @return {T}
 */
export function clone<T>(data: T, replacer?: (this: any, key: string, value: any) => any): T;
/**
 * @typedef { import('../types').Schema } Schema
 */
/**
 * Parse the schema for variables a form might make use of.
 *
 * @example
 *
 * // retrieve variables from schema
 * const variables = getSchemaVariables(schema);
 *
 * @example
 *
 * // retrieve input variables from schema
 * const inputVariables = getSchemaVariables(schema, { outputs: false });
 *
 * @example
 *
 * // retrieve output variables from schema
 * const outputVariables = getSchemaVariables(schema, { inputs: false });
 *
 * @param {Schema} schema
 * @param {object} [options]
 * @param {any} [options.expressionLanguage]
 * @param {any} [options.templating]
 * @param {any} [options.formFields]
 * @param {boolean} [options.inputs=true]
 * @param {boolean} [options.outputs=true]
 *
 * @return {string[]}
 */
export function getSchemaVariables(schema: Schema, options?: {
    expressionLanguage?: any;
    templating?: any;
    formFields?: any;
    inputs?: boolean;
    outputs?: boolean;
}): string[];
export function runRecursively(formField: any, fn: any): void;
export * from "./constants";
export * from "./injector";
export * from "./form";
export type Schema = import('../types').Schema;
